@@ -210,14 +210,6 @@ impl<T: NumEx> Vector<T> for XY<T> {
         }
     }
 
-    #[inline]
-    fn mul_add(self, b: Self, c: Self) -> Self {
-        Self {
-            x: self.x * b.x + c.x,
-            y: self.y * b.y + c.y,
-        }
-    }
-
     #[inline]
     fn sub(self, other: Self) -> Self {
         Self {
@@ -389,15 +381,6 @@ impl<T: NumEx> Vector<T> for XYZ<T> {
         }
     }
 
-    #[inline]
-    fn mul_add(self, b: Self, c: Self) -> Self {
-        Self {
-            x: self.x * b.x + c.x,
-            y: self.y * b.y + c.y,
-            z: self.z * b.z + c.z,
-        }
-    }
-
     #[inline]
     fn sub(self, other: Self) -> Self {
         Self {
@@ -591,16 +574,6 @@ impl<T: NumEx> Vector<T> for XYZW<T> {
         }
     }
 
-    #[inline]
-    fn mul_add(self, b: Self, c: Self) -> Self {
-        Self {
-            x: self.x * b.x + c.x,
-            y: self.y * b.y + c.y,
-            z: self.z * b.z + c.z,
-            w: self.w * b.w + c.w,
-        }
-    }
-
     #[inline]
     fn sub(self, other: Self) -> Self {
         Self {
@@ -1022,11 +995,6 @@ impl Vector<f32> for XYZF32A16 {
         XYZ::mul(self.into(), other.into()).into()
     }
 
-    #[inline]
-    fn mul_add(self, b: Self, c: Self) -> Self {
-        XYZ::mul_add(self.into(), b.into(), c.into()).into()
-    }
-
     #[inline]
     fn rem(self, other: Self) -> Self {
         XYZ::rem(self.into(), other.into()).into()
